#region Copyright Morrison Shwartz, Inc - Author: Jonah Stagner 
/////////////////////////////////////////////////////////////////////////
// Copyright Morrison Schwartz, Inc 2003-2004, All rights reserved     //
//---------------------------------------------------------------------//
//Author: Jonah L. Stagner                                             //
//---------------------------------------------------------------------//
// This product is protected by US Copyright laws and international    //
// treaties.  For more information, see the End User License Agreement //
// in the application installation folder.                             //
//---------------------------------------------------------------------//
// Visit us on the web at: http://www.ms-inc.net                       //
/////////////////////////////////////////////////////////////////////////
#endregion

using System;
using System.IO;
using System.Drawing;
using System.Reflection;
using System.Collections;
using System.Windows.Forms;

using SharpTools;
using SharpTools.DOM;
using SharpTools.Settings;
using SharpTools.PluginInterface;

namespace GooglePlugin
{

	/// <summary>
	/// Performs a Google search based on the text that is selected in the source code editor
	/// </summary>
	public class GooglePlugin : ISharpToolsPlugin
	{

		#region Private data members 

		internal static ArrayList			mruList;

		private SharpTools.Toolbar			toolbar;
		private SharpTools.ToolbarButton	cmdRun;

		#endregion 

		private Image GetIcon()
		{

			Type type = typeof(GooglePlugin);
			using( Stream imageStream = type.Assembly.GetManifestResourceStream( type.Namespace + "." + "GoogleIcon.png" ) )
			{
				Image img = Image.FromStream( imageStream );
				return img;
			}

		}

		#region ISharpToolsPlugin Members

		public string Description
		{
			get { return "Allows the developer to search on Google for text that is selected in the source code editor"; }
		}

		public string ID
		{
			get { return "SharpTools.Plugins.GooglePlugin"; }
		}

		public string Name
		{
			get { return "Google Search Plugin"; }
		}

		public void OnConnect()
		{

			// Attach this plugin to the SharpTools toolbar
			toolbar = new SharpTools.Toolbar( "SharpTools" );

			// Add a button to the toolbar which, when clicked, will 
			// add the custom header to the code files
			cmdRun = (SharpTools.ToolbarButton) toolbar.Controls.Add( ControlType.Button, "Google" );
			cmdRun.Caption = "Google";
			cmdRun.Tooltip = "Search Google";
			cmdRun.ButtonStyle = ButtonStyle.IconAndCaption;
			cmdRun.Picture = GetIcon();
			cmdRun.Click += new EventHandler(cmdRun_Click);

			// Read the list of most recently used (MRU) keywords
			ReadMRUList();

		}

		public void OnDisconnect(SharpTools.PluginInterface.DisconnectMode disconnectMode)
		{
			// TODO:  Add GooglePlugin.OnDisconnect implementation
		}

		#endregion

		private void cmdRun_Click(object sender, EventArgs e)
		{

			string keywords = "";

			TextSelection selection = Globals.ActiveSelection;
			if( selection != null && selection.Text.Trim() != "" )
				keywords = selection.Text.Trim();
			else
				keywords = EnterSearchText.GetKeywords( mruList );

			PerformSearch( keywords );

		}

		private void ReadMRUList()
		{

			mruList = new ArrayList();

			Properties mru = (Properties) Globals.Properties.GetProperty( "SharpTools.Plugins.Google.MRU", new Properties() );
			int count = mru.GetProperty( "Count", 0 );
			for( int i = 0; i < count; i++ )
			{
				string keywords = (string) mru.GetProperty( i.ToString(), "" );
				if( keywords != "" )
					mruList.Add( keywords );
			}

		}

		private void SaveMRUList()
		{

			while( mruList.Count > 25 )
				mruList.RemoveAt( mruList.Count - 1 );

			Properties mru = new Properties();
			mru.SetProperty( "Count", mruList.Count );
			for( int i = 0; i < mruList.Count; i++ )
				mru.SetProperty( i.ToString(), (string) mruList[i] );

			Globals.Properties.SetProperty( "SharpTools.Plugins.Google.MRU", mru );
			Globals.WriteApplicationSettings();
			
		}

		private void AddToMRUList( string keywords )
		{
			mruList.Insert( 0, keywords.Trim() );
			SaveMRUList();
		}

		public void PerformSearch( string keywords )
		{

			if( keywords == "" )
				return;

			AddToMRUList( keywords );

			string text = System.Web.HttpUtility.UrlEncode( keywords );
			string url = String.Format( "http://www.google.com/search?hl=en&ie=UTF-8&q={0}", text );
			
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			process.StartInfo.FileName = "iexplore.exe";
			process.StartInfo.Arguments = url;
			process.Start();

		}

	}

}
