using System;
using System.IO;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Data;
using System.Windows.Forms;

namespace RSSReader
{

	/// <summary>
	/// Adapts the System.Windows.Forms.Lable control to display a gradient background
	/// </summary>
	public class Label3D : System.Windows.Forms.Label
	{
		
		#region Private member variables 

		private Color shadowColor = Color.FromArgb( 0x00, 0x33, 0x99 );

		#endregion 

		public Label3D() : base()
		{

			// Set double-buffering to prevent flicker when drawing the control.
			SetStyle(ControlStyles.UserPaint, true);
			SetStyle(ControlStyles.AllPaintingInWmPaint, true);
			SetStyle(ControlStyles.DoubleBuffer, true);
			SetStyle(ControlStyles.Selectable, false);
			SetStyle(ControlStyles.SupportsTransparentBackColor, true);

		}

		#region Public properties 

		public Color ShadowColor
		{
			get { return shadowColor; }
			set { shadowColor = value; }
		}

		#endregion 

		protected override void OnPaint(PaintEventArgs e)
		{

			e.Graphics.SmoothingMode = SmoothingMode.AntiAlias;

			if( this.BackColor != Color.Transparent )
				e.Graphics.Clear( this.BackColor );

			SizeF maxTextArea = new SizeF( this.Width, this.Height );

			SizeF nameSize = e.Graphics.MeasureString( this.Text, this.Font, maxTextArea );
			RectangleF nameRect = new RectangleF(
				0,
				0,
				nameSize.Width,
				nameSize.Height
				);

			RectangleF shadowRect = new RectangleF( 
				nameRect.Left + 1,
				nameRect.Top + 1,
				nameRect.Width,
				nameRect.Height 
				);

			using( Brush brush = new SolidBrush( this.ShadowColor ) )
			{
				e.Graphics.DrawString( Text, Font, brush, shadowRect );
			}

			using( Brush brush = new SolidBrush( this.ForeColor ) )
			{
				e.Graphics.DrawString( Text, Font, brush, nameRect );
			}

		}


	}

}
